@@ -2,14 +2,19 @@
 tensorTRAX: Math on (Hyper-Dual) Tensors with Trailing Axes.
 """
 
-from ._tensor import Tensor
-from ._helpers import f, δ, Δ, Δδ
+from . import math
+from .__about__ import __version__
 from ._evaluate import (
     function,
-    jacobian,
     gradient,
-    hessian,
     gradient_vector_product,
+    hessian,
     hessian_vector_product,
+    jacobian,
 )
-from . import math
+from ._helpers import Δ, Δδ, f, δ
+from ._tensor import Tensor
+
+__all__ = [
+    "__version__",
+]
