@@ -10,10 +10,13 @@ r"""
 
 import numpy as np
 
-# from ..._tensor import Tensor, transpose,  matmul, f, δ, Δ, Δδ
-from .._math_tensor import trace, ddot, sqrt, transpose
 from .. import _math_array as array
 from .._linalg import _linalg_tensor as linalg
+from .._math_tensor import einsum, sqrt, trace, transpose
+
+
+def ddot(A, B):
+    return einsum("ij...,ij...->...", A, B)
 
 
 def dev(A):
